@@ -11,6 +11,7 @@ from ._shared import MORef
 from ._shared import OpenValidity
 from ._shared import Validity
 from .class_ import ClassRead
+from .class_ import ClassWrite
 from .employee import Employee
 from .employee import EmployeeRead
 from .employee import EmployeeWrite
@@ -27,6 +28,7 @@ from .organisation_unit import OrganisationUnitWrite
 
 __all__ = [
     "ClassRead",
+    "ClassWrite",
     "Employee",
     "EmployeeRead",
     "EmployeeWrite",
