@@ -17,6 +17,8 @@ from typing import Optional
 from pydantic import Field
 from pydantic import root_validator
 from pydantic import validator
+from ramodels.base import RABase
+from ramodels.base import tz_isodate
 
 from ._shared import MOBase
 from ._shared import OpenValidity
@@ -24,8 +26,6 @@ from ._shared import OrganisationRef
 from ._shared import validate_cpr
 from ._shared import validate_names
 from .details import EmployeeDetails
-from ramodels.base import RABase
-from ramodels.base import tz_isodate
 
 # --------------------------------------------------------------------------------------
 # Employee model
@@ -169,3 +169,8 @@ class Employee(MOBase):
 
 class EmployeeTerminate(RABase):
     validity: OpenValidity
+    vacate: Optional[bool] = Field(
+        description="Specifies if the termination was vacate related.. "
+        "Leaders & Owners are not allowed to be removed, they are just vacated.",
+        default=False,
+    )
